Class LangChainRetryableException

  • All Implemented Interfaces:
    java.io.Serializable

    
    public final class LangChainRetryableException
    extends LangChainException
                        

    Exception that indicates a transient error that can be retried.

    When this exception is thrown during an HTTP request, the SDK will automatically retry the request up to the maximum number of retries.

    • Constructor Detail

      • LangChainRetryableException

        LangChainRetryableException(String message, Throwable cause)
        Parameters:
        message - A descriptive error message
        cause - The underlying cause of this exception, if any
      • LangChainRetryableException

        LangChainRetryableException(String message)
        Parameters:
        message - A descriptive error message
      • LangChainRetryableException

        LangChainRetryableException()
    • Method Detail