Class AnnotationQueueCreateRunStatusResponse
-
- All Implemented Interfaces:
public final class AnnotationQueueCreateRunStatusResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAnnotationQueueCreateRunStatusResponse.BuilderA builder for AnnotationQueueCreateRunStatusResponse.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final AnnotationQueueCreateRunStatusResponse.BuildertoBuilder()final AnnotationQueueCreateRunStatusResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AnnotationQueueCreateRunStatusResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AnnotationQueueCreateRunStatusResponse. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AnnotationQueueCreateRunStatusResponse.Builder toBuilder()
-
validate
final AnnotationQueueCreateRunStatusResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AnnotationQueueCreateRunStatusResponse.Builder builder()
Returns a mutable builder for constructing an instance of AnnotationQueueCreateRunStatusResponse.
-
-
-
-