Class AnnotationQueueUpdateParams
-
- All Implemented Interfaces:
-
com.langchain.smith.core.Params
public final class AnnotationQueueUpdateParams implements Params
Update Annotation Queue
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAnnotationQueueUpdateParams.BuilderA builder for AnnotationQueueUpdateParams.
public final classAnnotationQueueUpdateParams.BodyAnnotationQueue update schema.
public final classAnnotationQueueUpdateParams.Metadatapublic final classAnnotationQueueUpdateParams.NumReviewersPerItempublic final classAnnotationQueueUpdateParams.ReviewerAccessMode
-
Method Summary
-
-
Method Detail
-
defaultDataset
final Optional<String> defaultDataset()
-
description
final Optional<String> description()
-
enableReservations
final Optional<Boolean> enableReservations()
-
metadata
final Optional<AnnotationQueueUpdateParams.Metadata> metadata()
-
numReviewersPerItem
final Optional<AnnotationQueueUpdateParams.NumReviewersPerItem> numReviewersPerItem()
-
reservationMinutes
final Optional<Long> reservationMinutes()
-
reviewerAccessMode
final Optional<AnnotationQueueUpdateParams.ReviewerAccessMode> reviewerAccessMode()
-
rubricInstructions
final Optional<String> rubricInstructions()
-
rubricItems
final Optional<List<AnnotationQueueRubricItemSchema>> rubricItems()
-
_defaultDataset
final JsonField<String> _defaultDataset()
Returns the raw JSON value of defaultDataset.
Unlike defaultDataset, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_enableReservations
final JsonField<Boolean> _enableReservations()
Returns the raw JSON value of enableReservations.
Unlike enableReservations, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<AnnotationQueueUpdateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_numReviewersPerItem
final JsonField<AnnotationQueueUpdateParams.NumReviewersPerItem> _numReviewersPerItem()
Returns the raw JSON value of numReviewersPerItem.
Unlike numReviewersPerItem, this method doesn't throw if the JSON field has an unexpected type.
-
_reservationMinutes
final JsonField<Long> _reservationMinutes()
Returns the raw JSON value of reservationMinutes.
Unlike reservationMinutes, this method doesn't throw if the JSON field has an unexpected type.
-
_reviewerAccessMode
final JsonField<AnnotationQueueUpdateParams.ReviewerAccessMode> _reviewerAccessMode()
Returns the raw JSON value of reviewerAccessMode.
Unlike reviewerAccessMode, this method doesn't throw if the JSON field has an unexpected type.
-
_rubricInstructions
final JsonField<String> _rubricInstructions()
Returns the raw JSON value of rubricInstructions.
Unlike rubricInstructions, this method doesn't throw if the JSON field has an unexpected type.
-
_rubricItems
final JsonField<List<AnnotationQueueRubricItemSchema>> _rubricItems()
Returns the raw JSON value of rubricItems.
Unlike rubricItems, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AnnotationQueueUpdateParams.Builder toBuilder()
-
_body
final AnnotationQueueUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AnnotationQueueUpdateParams none()
-
builder
final static AnnotationQueueUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of AnnotationQueueUpdateParams.
-
-
-
-