Class AnnotationQueueUpdateParams.Metadata
-
- All Implemented Interfaces:
public final class AnnotationQueueUpdateParams.Metadata
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAnnotationQueueUpdateParams.Metadata.VisitorAn interface that defines how to map each variant of Metadata to a value of type T.
public final classAnnotationQueueUpdateParams.Metadata.UnionMember0
-
Method Summary
Modifier and Type Method Description final Optional<AnnotationQueueUpdateParams.Metadata.UnionMember0>unionMember0()final Optional<Missing>missing()final Optional<JsonValue>_json()final BooleanisUnionMember0()final BooleanisMissing()final AnnotationQueueUpdateParams.Metadata.UnionMember0asUnionMember0()final MissingasMissing()final <T extends Any> Taccept(AnnotationQueueUpdateParams.Metadata.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final AnnotationQueueUpdateParams.Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AnnotationQueueUpdateParams.MetadataofUnionMember0(AnnotationQueueUpdateParams.Metadata.UnionMember0 unionMember0)final static AnnotationQueueUpdateParams.MetadataofMissing(Missing missing)-
-
Method Detail
-
unionMember0
final Optional<AnnotationQueueUpdateParams.Metadata.UnionMember0> unionMember0()
-
isUnionMember0
final Boolean isUnionMember0()
-
asUnionMember0
final AnnotationQueueUpdateParams.Metadata.UnionMember0 asUnionMember0()
-
accept
final <T extends Any> T accept(AnnotationQueueUpdateParams.Metadata.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.langchain.smith.core.JsonValue; import java.util.Optional; Optional<String> result = metadata.accept(new Metadata.Visitor<Optional<String>>() { @Override public Optional<String> visitUnionMember0(UnionMember0 unionMember0) { return Optional.of(unionMember0.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final AnnotationQueueUpdateParams.Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofUnionMember0
final static AnnotationQueueUpdateParams.Metadata ofUnionMember0(AnnotationQueueUpdateParams.Metadata.UnionMember0 unionMember0)
-
ofMissing
final static AnnotationQueueUpdateParams.Metadata ofMissing(Missing missing)
-
-
-
-