Class QueryExampleSchemaWithRuns
-
- All Implemented Interfaces:
public final class QueryExampleSchemaWithRuns
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classQueryExampleSchemaWithRuns.BuilderA builder for QueryExampleSchemaWithRuns.
public final classQueryExampleSchemaWithRuns.Filters
-
Method Summary
Modifier and Type Method Description final List<String>sessionIds()final Optional<String>comparativeExperimentId()final Optional<List<String>>exampleIds()final Optional<QueryExampleSchemaWithRuns.Filters>filters()final Optional<Boolean>includeAnnotatorDetail()final Optional<Long>limit()final Optional<Long>offset()final Optional<Boolean>preview()final Optional<SortParamsForRunsComparisonView>sortParams()final JsonField<List<String>>_sessionIds()Returns the raw JSON value of sessionIds. final JsonField<String>_comparativeExperimentId()Returns the raw JSON value of comparativeExperimentId. final JsonField<List<String>>_exampleIds()Returns the raw JSON value of exampleIds. final JsonField<QueryExampleSchemaWithRuns.Filters>_filters()Returns the raw JSON value of filters. final JsonField<Boolean>_includeAnnotatorDetail()Returns the raw JSON value of includeAnnotatorDetail. final JsonField<Long>_limit()Returns the raw JSON value of limit. final JsonField<Long>_offset()Returns the raw JSON value of offset. final JsonField<Boolean>_preview()Returns the raw JSON value of preview. final JsonField<SortParamsForRunsComparisonView>_sortParams()Returns the raw JSON value of sortParams. final Map<String, JsonValue>_additionalProperties()final QueryExampleSchemaWithRuns.BuildertoBuilder()final QueryExampleSchemaWithRunsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static QueryExampleSchemaWithRuns.Builderbuilder()Returns a mutable builder for constructing an instance of QueryExampleSchemaWithRuns. -
-
Method Detail
-
sessionIds
final List<String> sessionIds()
-
comparativeExperimentId
final Optional<String> comparativeExperimentId()
-
exampleIds
final Optional<List<String>> exampleIds()
-
filters
final Optional<QueryExampleSchemaWithRuns.Filters> filters()
-
includeAnnotatorDetail
final Optional<Boolean> includeAnnotatorDetail()
-
sortParams
final Optional<SortParamsForRunsComparisonView> sortParams()
-
_sessionIds
final JsonField<List<String>> _sessionIds()
Returns the raw JSON value of sessionIds.
Unlike sessionIds, this method doesn't throw if the JSON field has an unexpected type.
-
_comparativeExperimentId
final JsonField<String> _comparativeExperimentId()
Returns the raw JSON value of comparativeExperimentId.
Unlike comparativeExperimentId, this method doesn't throw if the JSON field has an unexpected type.
-
_exampleIds
final JsonField<List<String>> _exampleIds()
Returns the raw JSON value of exampleIds.
Unlike exampleIds, this method doesn't throw if the JSON field has an unexpected type.
-
_filters
final JsonField<QueryExampleSchemaWithRuns.Filters> _filters()
Returns the raw JSON value of filters.
Unlike filters, this method doesn't throw if the JSON field has an unexpected type.
-
_includeAnnotatorDetail
final JsonField<Boolean> _includeAnnotatorDetail()
Returns the raw JSON value of includeAnnotatorDetail.
Unlike includeAnnotatorDetail, this method doesn't throw if the JSON field has an unexpected type.
-
_limit
final JsonField<Long> _limit()
Returns the raw JSON value of limit.
Unlike limit, this method doesn't throw if the JSON field has an unexpected type.
-
_offset
final JsonField<Long> _offset()
Returns the raw JSON value of offset.
Unlike offset, this method doesn't throw if the JSON field has an unexpected type.
-
_preview
final JsonField<Boolean> _preview()
Returns the raw JSON value of preview.
Unlike preview, this method doesn't throw if the JSON field has an unexpected type.
-
_sortParams
final JsonField<SortParamsForRunsComparisonView> _sortParams()
Returns the raw JSON value of sortParams.
Unlike sortParams, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final QueryExampleSchemaWithRuns.Builder toBuilder()
-
validate
final QueryExampleSchemaWithRuns validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static QueryExampleSchemaWithRuns.Builder builder()
Returns a mutable builder for constructing an instance of QueryExampleSchemaWithRuns.
The following fields are required:
.sessionIds()
-
-
-
-