Class Example
-
- All Implemented Interfaces:
public final class ExampleExample schema.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExample.BuilderA builder for Example.
-
Method Summary
-
-
Method Detail
-
_attachmentUrls
final JsonValue _attachmentUrls()
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
modifiedAt
final Optional<OffsetDateTime> modifiedAt()
-
sourceRunId
final Optional<String> sourceRunId()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_datasetId
final JsonField<String> _datasetId()
Returns the raw JSON value of datasetId.
Unlike datasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_modifiedAt
final JsonField<OffsetDateTime> _modifiedAt()
Returns the raw JSON value of modifiedAt.
Unlike modifiedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceRunId
final JsonField<String> _sourceRunId()
Returns the raw JSON value of sourceRunId.
Unlike sourceRunId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Example.Builder toBuilder()
-
builder
final static Example.Builder builder()
Returns a mutable builder for constructing an instance of Example.
The following fields are required:
.id() .datasetId() .inputs() .name()
-
-
-
-