Class ExampleDeleteAllParams
-
- All Implemented Interfaces:
-
com.langchain.smith.core.Params
public final class ExampleDeleteAllParams implements Params
Soft delete examples. Only deletes the examples in the 'latest' version of the dataset.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleDeleteAllParams.BuilderA builder for ExampleDeleteAllParams.
-
Method Summary
Modifier and Type Method Description final List<String>exampleIds()final Map<String, JsonValue>_additionalBodyProperties()Additional body properties to send with the request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExampleDeleteAllParams.BuildertoBuilder()final Optional<Map<String, JsonValue>>_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExampleDeleteAllParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExampleDeleteAllParams. -
-
Method Detail
-
exampleIds
final List<String> exampleIds()
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
Additional body properties to send with the request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExampleDeleteAllParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ExampleDeleteAllParams.Builder builder()
Returns a mutable builder for constructing an instance of ExampleDeleteAllParams.
The following fields are required:
.exampleIds()
-
-
-
-