Class ExampleDeleteAllResponse
-
- All Implemented Interfaces:
public final class ExampleDeleteAllResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleDeleteAllResponse.BuilderA builder for ExampleDeleteAllResponse.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ExampleDeleteAllResponse.BuildertoBuilder()final ExampleDeleteAllResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExampleDeleteAllResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ExampleDeleteAllResponse. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExampleDeleteAllResponse.Builder toBuilder()
-
validate
final ExampleDeleteAllResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExampleDeleteAllResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExampleDeleteAllResponse.
-
-
-
-