Class ExampleDeleteResponse
-
- All Implemented Interfaces:
public final class ExampleDeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleDeleteResponse.BuilderA builder for ExampleDeleteResponse.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ExampleDeleteResponse.BuildertoBuilder()final ExampleDeleteResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExampleDeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ExampleDeleteResponse. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExampleDeleteResponse.Builder toBuilder()
-
validate
final ExampleDeleteResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExampleDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExampleDeleteResponse.
-
-
-
-