Class ExampleListPageAsync
-
- All Implemented Interfaces:
-
com.langchain.smith.core.PageAsync
public final class ExampleListPageAsync implements PageAsync<Example>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleListPageAsync.BuilderA builder for ExampleListPageAsync.
-
Method Summary
Modifier and Type Method Description final ExampleListParamsparams()The parameters that were used to request this page. List<Example>items()The response that this page was parsed from. BooleanhasNextPage()Returns whether there's another page after this one. final ExampleListParamsnextPageParams()CompletableFuture<ExampleListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<Example>autoPager()final ExampleListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExampleListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of ExampleListPageAsync. -
-
Method Detail
-
params
final ExampleListParams params()
The parameters that were used to request this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final ExampleListParams nextPageParams()
-
nextPage
CompletableFuture<ExampleListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<Example> autoPager()
-
toBuilder
final ExampleListPageAsync.Builder toBuilder()
-
builder
final static ExampleListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ExampleListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .items()
-
-
-
-