Class ExampleListParams
-
- All Implemented Interfaces:
-
com.langchain.smith.core.Params
public final class ExampleListParams implements Params
Get all examples by query params
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleListParams.BuilderA builder for ExampleListParams.
public final classExampleListParams.AsOfOnly modifications made on or before this time are included. If None, the latest version of the dataset is used.
public final classExampleListParams.Order
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>id()final Optional<ExampleListParams.AsOf>asOf()Only modifications made on or before this time are included. final Optional<String>dataset()final Optional<Boolean>descending()final Optional<String>filter()final Optional<List<String>>fullTextContains()final Optional<Long>limit()final Optional<String>metadata()final Optional<Long>offset()final Optional<ExampleListParams.Order>order()final Optional<Double>randomSeed()final Optional<List<ExampleSelect>>select()final Optional<List<String>>splits()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExampleListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExampleListParamsnone()final static ExampleListParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExampleListParams. -
-
Method Detail
-
asOf
final Optional<ExampleListParams.AsOf> asOf()
Only modifications made on or before this time are included. If None, the latest version of the dataset is used.
-
descending
final Optional<Boolean> descending()
-
fullTextContains
final Optional<List<String>> fullTextContains()
-
order
final Optional<ExampleListParams.Order> order()
-
randomSeed
final Optional<Double> randomSeed()
-
select
final Optional<List<ExampleSelect>> select()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExampleListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ExampleListParams none()
-
builder
final static ExampleListParams.Builder builder()
Returns a mutable builder for constructing an instance of ExampleListParams.
-
-
-
-