Class ExampleUpdateParams
-
- All Implemented Interfaces:
-
com.langchain.smith.core.Params
public final class ExampleUpdateParams implements Params
Update a specific example.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleUpdateParams.BuilderA builder for ExampleUpdateParams.
public final classExampleUpdateParams.BodyUpdate class for Example.
public final classExampleUpdateParams.Split
-
Method Summary
Modifier and Type Method Description final Optional<String>exampleId()final Optional<AttachmentsOperations>attachmentsOperations()final Optional<String>datasetId()final JsonValue_inputs()final JsonValue_metadata()final JsonValue_outputs()final Optional<Boolean>overwrite()final Optional<ExampleUpdateParams.Split>split()final JsonField<AttachmentsOperations>_attachmentsOperations()Returns the raw JSON value of attachmentsOperations. final JsonField<String>_datasetId()Returns the raw JSON value of datasetId. final JsonField<Boolean>_overwrite()Returns the raw JSON value of overwrite. final JsonField<ExampleUpdateParams.Split>_split()Returns the raw JSON value of split. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExampleUpdateParams.BuildertoBuilder()final ExampleUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExampleUpdateParamsnone()final static ExampleUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExampleUpdateParams. -
-
Method Detail
-
attachmentsOperations
final Optional<AttachmentsOperations> attachmentsOperations()
-
split
final Optional<ExampleUpdateParams.Split> split()
-
_attachmentsOperations
final JsonField<AttachmentsOperations> _attachmentsOperations()
Returns the raw JSON value of attachmentsOperations.
Unlike attachmentsOperations, this method doesn't throw if the JSON field has an unexpected type.
-
_datasetId
final JsonField<String> _datasetId()
Returns the raw JSON value of datasetId.
Unlike datasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_overwrite
final JsonField<Boolean> _overwrite()
Returns the raw JSON value of overwrite.
Unlike overwrite, this method doesn't throw if the JSON field has an unexpected type.
-
_split
final JsonField<ExampleUpdateParams.Split> _split()
Returns the raw JSON value of split.
Unlike split, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExampleUpdateParams.Builder toBuilder()
-
_body
final ExampleUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ExampleUpdateParams none()
-
builder
final static ExampleUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of ExampleUpdateParams.
-
-
-
-