Class ExampleUpdateParams.Body
-
- All Implemented Interfaces:
public final class ExampleUpdateParams.BodyUpdate class for Example.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
attachmentsOperations
final Optional<AttachmentsOperations> attachmentsOperations()
-
inputs
final Optional<ExampleUpdateParams.Inputs> inputs()
-
metadata
final Optional<ExampleUpdateParams.Metadata> metadata()
-
outputs
final Optional<ExampleUpdateParams.Outputs> outputs()
-
split
final Optional<ExampleUpdateParams.Split> split()
-
_attachmentsOperations
final JsonField<AttachmentsOperations> _attachmentsOperations()
Returns the raw JSON value of attachmentsOperations.
Unlike attachmentsOperations, this method doesn't throw if the JSON field has an unexpected type.
-
_datasetId
final JsonField<String> _datasetId()
Returns the raw JSON value of datasetId.
Unlike datasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_inputs
final JsonField<ExampleUpdateParams.Inputs> _inputs()
Returns the raw JSON value of inputs.
Unlike inputs, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<ExampleUpdateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_outputs
final JsonField<ExampleUpdateParams.Outputs> _outputs()
Returns the raw JSON value of outputs.
Unlike outputs, this method doesn't throw if the JSON field has an unexpected type.
-
_overwrite
final JsonField<Boolean> _overwrite()
Returns the raw JSON value of overwrite.
Unlike overwrite, this method doesn't throw if the JSON field has an unexpected type.
-
_split
final JsonField<ExampleUpdateParams.Split> _split()
Returns the raw JSON value of split.
Unlike split, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExampleUpdateParams.Body.Builder toBuilder()
-
validate
final ExampleUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExampleUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-