Class ExampleUpdateResponse
-
- All Implemented Interfaces:
public final class ExampleUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleUpdateResponse.BuilderA builder for ExampleUpdateResponse.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ExampleUpdateResponse.BuildertoBuilder()final ExampleUpdateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExampleUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ExampleUpdateResponse. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExampleUpdateResponse.Builder toBuilder()
-
validate
final ExampleUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExampleUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExampleUpdateResponse.
-
-
-
-