Class ExampleValidationResult
-
- All Implemented Interfaces:
public final class ExampleValidationResultValidation result for Example, combining fields from Create/Base/Update schemas.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleValidationResult.BuilderA builder for ExampleValidationResult.
public final classExampleValidationResult.Split
-
Method Summary
-
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
sourceRunId
final Optional<String> sourceRunId()
-
split
final Optional<ExampleValidationResult.Split> split()
-
useSourceRunIo
final Optional<Boolean> useSourceRunIo()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_datasetId
final JsonField<String> _datasetId()
Returns the raw JSON value of datasetId.
Unlike datasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_overwrite
final JsonField<Boolean> _overwrite()
Returns the raw JSON value of overwrite.
Unlike overwrite, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceRunId
final JsonField<String> _sourceRunId()
Returns the raw JSON value of sourceRunId.
Unlike sourceRunId, this method doesn't throw if the JSON field has an unexpected type.
-
_split
final JsonField<ExampleValidationResult.Split> _split()
Returns the raw JSON value of split.
Unlike split, this method doesn't throw if the JSON field has an unexpected type.
-
_useSourceRunIo
final JsonField<Boolean> _useSourceRunIo()
Returns the raw JSON value of useSourceRunIo.
Unlike useSourceRunIo, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExampleValidationResult.Builder toBuilder()
-
validate
final ExampleValidationResult validate()
-
builder
final static ExampleValidationResult.Builder builder()
Returns a mutable builder for constructing an instance of ExampleValidationResult.
-
-
-
-