Class WorkspaceCreateParams
-
- All Implemented Interfaces:
-
com.langchain.smith.core.Params
public final class WorkspaceCreateParams implements Params
Create a new workspace.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkspaceCreateParams.BuilderA builder for WorkspaceCreateParams.
public final classWorkspaceCreateParams.BodyCreation model for the workspace.
-
Method Summary
Modifier and Type Method Description final StringdisplayName()final Optional<String>id()final Optional<String>tenantHandle()final JsonField<String>_displayName()Returns the raw JSON value of displayName. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_tenantHandle()Returns the raw JSON value of tenantHandle. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final WorkspaceCreateParams.BuildertoBuilder()final WorkspaceCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static WorkspaceCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of WorkspaceCreateParams. -
-
Method Detail
-
displayName
final String displayName()
-
tenantHandle
final Optional<String> tenantHandle()
-
_displayName
final JsonField<String> _displayName()
Returns the raw JSON value of displayName.
Unlike displayName, this method doesn't throw if the JSON field has an unexpected type.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_tenantHandle
final JsonField<String> _tenantHandle()
Returns the raw JSON value of tenantHandle.
Unlike tenantHandle, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final WorkspaceCreateParams.Builder toBuilder()
-
_body
final WorkspaceCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static WorkspaceCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of WorkspaceCreateParams.
The following fields are required:
.displayName()
-
-
-
-