Class WorkspaceCreateResponse
-
- All Implemented Interfaces:
public final class WorkspaceCreateResponseTenant schema.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkspaceCreateResponse.BuilderA builder for WorkspaceCreateResponse.
-
Method Summary
Modifier and Type Method Description final Stringid()final OffsetDateTimecreatedAt()final StringdisplayName()final BooleanisDeleted()final BooleanisPersonal()final Optional<String>dataPlaneUrl()final Optional<String>organizationId()final Optional<String>tenantHandle()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_displayName()Returns the raw JSON value of displayName. final JsonField<Boolean>_isDeleted()Returns the raw JSON value of isDeleted. final JsonField<Boolean>_isPersonal()Returns the raw JSON value of isPersonal. final JsonField<String>_dataPlaneUrl()Returns the raw JSON value of dataPlaneUrl. final JsonField<String>_organizationId()Returns the raw JSON value of organizationId. final JsonField<String>_tenantHandle()Returns the raw JSON value of tenantHandle. final Map<String, JsonValue>_additionalProperties()final WorkspaceCreateResponse.BuildertoBuilder()final WorkspaceCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WorkspaceCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WorkspaceCreateResponse. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
-
displayName
final String displayName()
-
isPersonal
final Boolean isPersonal()
-
dataPlaneUrl
final Optional<String> dataPlaneUrl()
-
organizationId
final Optional<String> organizationId()
-
tenantHandle
final Optional<String> tenantHandle()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_displayName
final JsonField<String> _displayName()
Returns the raw JSON value of displayName.
Unlike displayName, this method doesn't throw if the JSON field has an unexpected type.
-
_isDeleted
final JsonField<Boolean> _isDeleted()
Returns the raw JSON value of isDeleted.
Unlike isDeleted, this method doesn't throw if the JSON field has an unexpected type.
-
_isPersonal
final JsonField<Boolean> _isPersonal()
Returns the raw JSON value of isPersonal.
Unlike isPersonal, this method doesn't throw if the JSON field has an unexpected type.
-
_dataPlaneUrl
final JsonField<String> _dataPlaneUrl()
Returns the raw JSON value of dataPlaneUrl.
Unlike dataPlaneUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_organizationId
final JsonField<String> _organizationId()
Returns the raw JSON value of organizationId.
Unlike organizationId, this method doesn't throw if the JSON field has an unexpected type.
-
_tenantHandle
final JsonField<String> _tenantHandle()
Returns the raw JSON value of tenantHandle.
Unlike tenantHandle, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WorkspaceCreateResponse.Builder toBuilder()
-
validate
final WorkspaceCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WorkspaceCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of WorkspaceCreateResponse.
The following fields are required:
.id() .createdAt() .displayName() .isDeleted() .isPersonal()
-
-
-
-