Class WorkspaceRetrieveResponse
-
- All Implemented Interfaces:
public final class WorkspaceRetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkspaceRetrieveResponse.BuilderA builder for WorkspaceRetrieveResponse.
-
Method Summary
Modifier and Type Method Description final Stringid()final OffsetDateTimecreatedAt()final StringdisplayName()final BooleanisDeleted()final BooleanisPersonal()final Optional<String>dataPlaneUrl()final Optional<String>organizationId()final Optional<List<String>>permissions()final Optional<Boolean>readOnly()final Optional<String>roleId()final Optional<String>roleName()final Optional<String>tenantHandle()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_displayName()Returns the raw JSON value of displayName. final JsonField<Boolean>_isDeleted()Returns the raw JSON value of isDeleted. final JsonField<Boolean>_isPersonal()Returns the raw JSON value of isPersonal. final JsonField<String>_dataPlaneUrl()Returns the raw JSON value of dataPlaneUrl. final JsonField<String>_organizationId()Returns the raw JSON value of organizationId. final JsonField<List<String>>_permissions()Returns the raw JSON value of permissions. final JsonField<Boolean>_readOnly()Returns the raw JSON value of readOnly. final JsonField<String>_roleId()Returns the raw JSON value of roleId. final JsonField<String>_roleName()Returns the raw JSON value of roleName. final JsonField<String>_tenantHandle()Returns the raw JSON value of tenantHandle. final Map<String, JsonValue>_additionalProperties()final WorkspaceRetrieveResponse.BuildertoBuilder()final WorkspaceRetrieveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WorkspaceRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WorkspaceRetrieveResponse. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
-
displayName
final String displayName()
-
isPersonal
final Boolean isPersonal()
-
dataPlaneUrl
final Optional<String> dataPlaneUrl()
-
organizationId
final Optional<String> organizationId()
-
permissions
final Optional<List<String>> permissions()
-
readOnly
@Deprecated(message = "deprecated") final Optional<Boolean> readOnly()
-
tenantHandle
final Optional<String> tenantHandle()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_displayName
final JsonField<String> _displayName()
Returns the raw JSON value of displayName.
Unlike displayName, this method doesn't throw if the JSON field has an unexpected type.
-
_isDeleted
final JsonField<Boolean> _isDeleted()
Returns the raw JSON value of isDeleted.
Unlike isDeleted, this method doesn't throw if the JSON field has an unexpected type.
-
_isPersonal
final JsonField<Boolean> _isPersonal()
Returns the raw JSON value of isPersonal.
Unlike isPersonal, this method doesn't throw if the JSON field has an unexpected type.
-
_dataPlaneUrl
final JsonField<String> _dataPlaneUrl()
Returns the raw JSON value of dataPlaneUrl.
Unlike dataPlaneUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_organizationId
final JsonField<String> _organizationId()
Returns the raw JSON value of organizationId.
Unlike organizationId, this method doesn't throw if the JSON field has an unexpected type.
-
_permissions
final JsonField<List<String>> _permissions()
Returns the raw JSON value of permissions.
Unlike permissions, this method doesn't throw if the JSON field has an unexpected type.
-
_readOnly
@Deprecated(message = "deprecated") final JsonField<Boolean> _readOnly()
Returns the raw JSON value of readOnly.
Unlike readOnly, this method doesn't throw if the JSON field has an unexpected type.
-
_roleId
final JsonField<String> _roleId()
Returns the raw JSON value of roleId.
Unlike roleId, this method doesn't throw if the JSON field has an unexpected type.
-
_roleName
final JsonField<String> _roleName()
Returns the raw JSON value of roleName.
Unlike roleName, this method doesn't throw if the JSON field has an unexpected type.
-
_tenantHandle
final JsonField<String> _tenantHandle()
Returns the raw JSON value of tenantHandle.
Unlike tenantHandle, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WorkspaceRetrieveResponse.Builder toBuilder()
-
validate
final WorkspaceRetrieveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WorkspaceRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of WorkspaceRetrieveResponse.
The following fields are required:
.id() .createdAt() .displayName() .isDeleted() .isPersonal()
-
-
-
-