Interface AnnotationQueueServiceAsync
-
- All Implemented Interfaces:
public interface AnnotationQueueServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAnnotationQueueServiceAsync.WithRawResponseA view of AnnotationQueueServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AnnotationQueueServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AnnotationQueueServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
runs
abstract RunServiceAsync runs()
-
retrieve
CompletableFuture<AnnotationQueueRetrieveResponse> retrieve(String queueId)
Get Annotation Queue
-
retrieve
CompletableFuture<AnnotationQueueRetrieveResponse> retrieve(String queueId, AnnotationQueueRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AnnotationQueueRetrieveResponse> retrieve(String queueId, AnnotationQueueRetrieveParams params)
-
retrieve
abstract CompletableFuture<AnnotationQueueRetrieveResponse> retrieve(AnnotationQueueRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AnnotationQueueRetrieveResponse> retrieve(AnnotationQueueRetrieveParams params)
-
retrieve
CompletableFuture<AnnotationQueueRetrieveResponse> retrieve(String queueId, RequestOptions requestOptions)
-
update
CompletableFuture<AnnotationQueueUpdateResponse> update(String queueId)
Update Annotation Queue
-
update
CompletableFuture<AnnotationQueueUpdateResponse> update(String queueId, AnnotationQueueUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<AnnotationQueueUpdateResponse> update(String queueId, AnnotationQueueUpdateParams params)
-
update
abstract CompletableFuture<AnnotationQueueUpdateResponse> update(AnnotationQueueUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<AnnotationQueueUpdateResponse> update(String queueId, RequestOptions requestOptions)
-
delete
CompletableFuture<AnnotationQueueDeleteResponse> delete(String queueId)
Delete Annotation Queue
-
delete
CompletableFuture<AnnotationQueueDeleteResponse> delete(String queueId, AnnotationQueueDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<AnnotationQueueDeleteResponse> delete(String queueId, AnnotationQueueDeleteParams params)
-
delete
abstract CompletableFuture<AnnotationQueueDeleteResponse> delete(AnnotationQueueDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<AnnotationQueueDeleteResponse> delete(String queueId, RequestOptions requestOptions)
-
annotationQueues
CompletableFuture<AnnotationQueueSchema> annotationQueues(AnnotationQueueAnnotationQueuesParams params)
Create Annotation Queue
-
annotationQueues
abstract CompletableFuture<AnnotationQueueSchema> annotationQueues(AnnotationQueueAnnotationQueuesParams params, RequestOptions requestOptions)
-
createRunStatus
CompletableFuture<AnnotationQueueCreateRunStatusResponse> createRunStatus(String annotationQueueRunId)
Create Identity Annotation Queue Run Status
-
createRunStatus
CompletableFuture<AnnotationQueueCreateRunStatusResponse> createRunStatus(String annotationQueueRunId, AnnotationQueueCreateRunStatusParams params, RequestOptions requestOptions)
-
createRunStatus
CompletableFuture<AnnotationQueueCreateRunStatusResponse> createRunStatus(String annotationQueueRunId, AnnotationQueueCreateRunStatusParams params)
-
createRunStatus
abstract CompletableFuture<AnnotationQueueCreateRunStatusResponse> createRunStatus(AnnotationQueueCreateRunStatusParams params, RequestOptions requestOptions)
-
createRunStatus
CompletableFuture<AnnotationQueueCreateRunStatusResponse> createRunStatus(AnnotationQueueCreateRunStatusParams params)
-
createRunStatus
CompletableFuture<AnnotationQueueCreateRunStatusResponse> createRunStatus(String annotationQueueRunId, RequestOptions requestOptions)
-
export
CompletableFuture<AnnotationQueueExportResponse> export(String queueId)
Export Annotation Queue Archived Runs
-
export
CompletableFuture<AnnotationQueueExportResponse> export(String queueId, AnnotationQueueExportParams params, RequestOptions requestOptions)
-
export
CompletableFuture<AnnotationQueueExportResponse> export(String queueId, AnnotationQueueExportParams params)
-
export
abstract CompletableFuture<AnnotationQueueExportResponse> export(AnnotationQueueExportParams params, RequestOptions requestOptions)
-
export
CompletableFuture<AnnotationQueueExportResponse> export(String queueId, RequestOptions requestOptions)
-
populate
CompletableFuture<AnnotationQueuePopulateResponse> populate(AnnotationQueuePopulateParams params)
Populate annotation queue with runs from an experiment.
-
populate
abstract CompletableFuture<AnnotationQueuePopulateResponse> populate(AnnotationQueuePopulateParams params, RequestOptions requestOptions)
-
retrieveAnnotationQueues
CompletableFuture<List<AnnotationQueueRetrieveAnnotationQueuesResponse>> retrieveAnnotationQueues()
Get Annotation Queues
-
retrieveAnnotationQueues
abstract CompletableFuture<List<AnnotationQueueRetrieveAnnotationQueuesResponse>> retrieveAnnotationQueues(AnnotationQueueRetrieveAnnotationQueuesParams params, RequestOptions requestOptions)
-
retrieveAnnotationQueues
CompletableFuture<List<AnnotationQueueRetrieveAnnotationQueuesResponse>> retrieveAnnotationQueues(AnnotationQueueRetrieveAnnotationQueuesParams params)
-
retrieveAnnotationQueues
CompletableFuture<List<AnnotationQueueRetrieveAnnotationQueuesResponse>> retrieveAnnotationQueues(RequestOptions requestOptions)
-
retrieveQueues
CompletableFuture<List<AnnotationQueueSchema>> retrieveQueues(String runId)
Get Annotation Queues For Run
-
retrieveQueues
CompletableFuture<List<AnnotationQueueSchema>> retrieveQueues(String runId, AnnotationQueueRetrieveQueuesParams params, RequestOptions requestOptions)
-
retrieveQueues
CompletableFuture<List<AnnotationQueueSchema>> retrieveQueues(String runId, AnnotationQueueRetrieveQueuesParams params)
-
retrieveQueues
abstract CompletableFuture<List<AnnotationQueueSchema>> retrieveQueues(AnnotationQueueRetrieveQueuesParams params, RequestOptions requestOptions)
-
retrieveQueues
CompletableFuture<List<AnnotationQueueSchema>> retrieveQueues(AnnotationQueueRetrieveQueuesParams params)
-
retrieveQueues
CompletableFuture<List<AnnotationQueueSchema>> retrieveQueues(String runId, RequestOptions requestOptions)
-
retrieveRun
CompletableFuture<RunSchemaWithAnnotationQueueInfo> retrieveRun(Long index, AnnotationQueueRetrieveRunParams params)
Get a run from an annotation queue
-
retrieveRun
CompletableFuture<RunSchemaWithAnnotationQueueInfo> retrieveRun(Long index, AnnotationQueueRetrieveRunParams params, RequestOptions requestOptions)
-
retrieveRun
CompletableFuture<RunSchemaWithAnnotationQueueInfo> retrieveRun(AnnotationQueueRetrieveRunParams params)
-
retrieveRun
abstract CompletableFuture<RunSchemaWithAnnotationQueueInfo> retrieveRun(AnnotationQueueRetrieveRunParams params, RequestOptions requestOptions)
-
retrieveSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveSize(String queueId)
Get Size From Annotation Queue
-
retrieveSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveSize(String queueId, AnnotationQueueRetrieveSizeParams params, RequestOptions requestOptions)
-
retrieveSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveSize(String queueId, AnnotationQueueRetrieveSizeParams params)
-
retrieveSize
abstract CompletableFuture<AnnotationQueueSizeSchema> retrieveSize(AnnotationQueueRetrieveSizeParams params, RequestOptions requestOptions)
-
retrieveSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveSize(AnnotationQueueRetrieveSizeParams params)
-
retrieveSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveSize(String queueId, RequestOptions requestOptions)
-
retrieveTotalArchived
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalArchived(String queueId)
Get Total Archived From Annotation Queue
-
retrieveTotalArchived
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalArchived(String queueId, AnnotationQueueRetrieveTotalArchivedParams params, RequestOptions requestOptions)
-
retrieveTotalArchived
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalArchived(String queueId, AnnotationQueueRetrieveTotalArchivedParams params)
-
retrieveTotalArchived
abstract CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalArchived(AnnotationQueueRetrieveTotalArchivedParams params, RequestOptions requestOptions)
-
retrieveTotalArchived
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalArchived(AnnotationQueueRetrieveTotalArchivedParams params)
-
retrieveTotalArchived
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalArchived(String queueId, RequestOptions requestOptions)
-
retrieveTotalSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalSize(String queueId)
Get Total Size From Annotation Queue
-
retrieveTotalSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalSize(String queueId, AnnotationQueueRetrieveTotalSizeParams params, RequestOptions requestOptions)
-
retrieveTotalSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalSize(String queueId, AnnotationQueueRetrieveTotalSizeParams params)
-
retrieveTotalSize
abstract CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalSize(AnnotationQueueRetrieveTotalSizeParams params, RequestOptions requestOptions)
-
retrieveTotalSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalSize(AnnotationQueueRetrieveTotalSizeParams params)
-
retrieveTotalSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalSize(String queueId, RequestOptions requestOptions)
-
-
-
-