Class AnnotationQueueServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.async.AnnotationQueueServiceAsync
public final class AnnotationQueueServiceAsyncImpl implements AnnotationQueueServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAnnotationQueueServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.langchain.smith.services.async.AnnotationQueueServiceAsync
annotationQueues, createRunStatus, createRunStatus, createRunStatus, createRunStatus, createRunStatus, delete, delete, delete, delete, delete, export, export, export, export, export, populate, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveAnnotationQueues, retrieveAnnotationQueues, retrieveAnnotationQueues, retrieveQueues, retrieveQueues, retrieveQueues, retrieveQueues, retrieveQueues, retrieveRun, retrieveRun, retrieveRun, retrieveSize, retrieveSize, retrieveSize, retrieveSize, retrieveSize, retrieveTotalArchived, retrieveTotalArchived, retrieveTotalArchived, retrieveTotalArchived, retrieveTotalArchived, retrieveTotalSize, retrieveTotalSize, retrieveTotalSize, retrieveTotalSize, retrieveTotalSize, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
AnnotationQueueServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
runs
RunServiceAsync runs()
-
withOptions
AnnotationQueueServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<AnnotationQueueRetrieveResponse> retrieve(AnnotationQueueRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<AnnotationQueueUpdateResponse> update(AnnotationQueueUpdateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<AnnotationQueueDeleteResponse> delete(AnnotationQueueDeleteParams params, RequestOptions requestOptions)
-
annotationQueues
CompletableFuture<AnnotationQueueSchema> annotationQueues(AnnotationQueueAnnotationQueuesParams params, RequestOptions requestOptions)
-
createRunStatus
CompletableFuture<AnnotationQueueCreateRunStatusResponse> createRunStatus(AnnotationQueueCreateRunStatusParams params, RequestOptions requestOptions)
-
export
CompletableFuture<AnnotationQueueExportResponse> export(AnnotationQueueExportParams params, RequestOptions requestOptions)
-
populate
CompletableFuture<AnnotationQueuePopulateResponse> populate(AnnotationQueuePopulateParams params, RequestOptions requestOptions)
-
retrieveAnnotationQueues
CompletableFuture<AnnotationQueueRetrieveAnnotationQueuesPageAsync> retrieveAnnotationQueues(AnnotationQueueRetrieveAnnotationQueuesParams params, RequestOptions requestOptions)
-
retrieveQueues
CompletableFuture<List<AnnotationQueueSchema>> retrieveQueues(AnnotationQueueRetrieveQueuesParams params, RequestOptions requestOptions)
-
retrieveRun
CompletableFuture<RunSchemaWithAnnotationQueueInfo> retrieveRun(AnnotationQueueRetrieveRunParams params, RequestOptions requestOptions)
-
retrieveSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveSize(AnnotationQueueRetrieveSizeParams params, RequestOptions requestOptions)
-
retrieveTotalArchived
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalArchived(AnnotationQueueRetrieveTotalArchivedParams params, RequestOptions requestOptions)
-
retrieveTotalSize
CompletableFuture<AnnotationQueueSizeSchema> retrieveTotalSize(AnnotationQueueRetrieveTotalSizeParams params, RequestOptions requestOptions)
-
-
-
-