Class ExampleServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.async.ExampleServiceAsync
public final class ExampleServiceAsyncImpl implements ExampleServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.langchain.smith.services.async.ExampleServiceAsync
create, delete, delete, delete, delete, delete, deleteAll, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveCount, retrieveCount, retrieveCount, update, update, update, update, update, uploadFromCsv, uploadFromCsv, uploadFromCsv -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ExampleServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
bulk
BulkServiceAsync bulk()
-
validate
ValidateServiceAsync validate()
-
withOptions
ExampleServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Example> create(ExampleCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Example> retrieve(ExampleRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ExampleUpdateResponse> update(ExampleUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExampleListPageAsync> list(ExampleListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<ExampleDeleteResponse> delete(ExampleDeleteParams params, RequestOptions requestOptions)
-
deleteAll
CompletableFuture<ExampleDeleteAllResponse> deleteAll(ExampleDeleteAllParams params, RequestOptions requestOptions)
-
retrieveCount
CompletableFuture<Long> retrieveCount(ExampleRetrieveCountParams params, RequestOptions requestOptions)
-
uploadFromCsv
CompletableFuture<List<Example>> uploadFromCsv(ExampleUploadFromCsvParams params, RequestOptions requestOptions)
-
-
-
-