Class SessionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.async.SessionServiceAsync
public final class SessionServiceAsyncImpl implements SessionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSessionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.langchain.smith.services.async.SessionServiceAsync
create, create, create, dashboard, dashboard, dashboard, delete, delete, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SessionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
insights
InsightServiceAsync insights()
-
withOptions
SessionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<TracerSessionWithoutVirtualFields> create(SessionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<TracerSession> retrieve(SessionRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<TracerSessionWithoutVirtualFields> update(SessionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<SessionListPageAsync> list(SessionListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<SessionDeleteResponse> delete(SessionDeleteParams params, RequestOptions requestOptions)
-
dashboard
CompletableFuture<CustomChartsSection> dashboard(SessionDashboardParams params, RequestOptions requestOptions)
-
-
-
-