Interface SettingServiceAsync
-
- All Implemented Interfaces:
public interface SettingServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSettingServiceAsync.WithRawResponseA view of SettingServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SettingServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SettingServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AppHubCrudTenantsTenant>list()Get settings. abstract CompletableFuture<AppHubCrudTenantsTenant>list(SettingListParams params, RequestOptions requestOptions)CompletableFuture<AppHubCrudTenantsTenant>list(SettingListParams params)CompletableFuture<AppHubCrudTenantsTenant>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SettingServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SettingServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<AppHubCrudTenantsTenant> list()
Get settings.
-
list
abstract CompletableFuture<AppHubCrudTenantsTenant> list(SettingListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AppHubCrudTenantsTenant> list(SettingListParams params)
-
list
CompletableFuture<AppHubCrudTenantsTenant> list(RequestOptions requestOptions)
-
-
-
-