Class SettingServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.async.SettingServiceAsync
public final class SettingServiceAsyncImpl implements SettingServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSettingServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SettingServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SettingServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AppHubCrudTenantsTenant>list(SettingListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SettingServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SettingServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<AppHubCrudTenantsTenant> list(SettingListParams params, RequestOptions requestOptions)
-
-
-
-