Interface ThreadServiceAsync
-
- All Implemented Interfaces:
public interface ThreadServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceThreadServiceAsync.WithRawResponseA view of ThreadServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ThreadServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ThreadServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ThreadListTracesPageAsync>listTraces(String threadId, ThreadListTracesParams params)Alpha: The request and response contract may change; Retrieve all traces belonging to a specific thread within a project. CompletableFuture<ThreadListTracesPageAsync>listTraces(String threadId, ThreadListTracesParams params, RequestOptions requestOptions)CompletableFuture<ThreadListTracesPageAsync>listTraces(ThreadListTracesParams params)abstract CompletableFuture<ThreadListTracesPageAsync>listTraces(ThreadListTracesParams params, RequestOptions requestOptions)CompletableFuture<ThreadQueryPageAsync>query()Alpha: The request and response contract may change; Query threads within a project (session), with cursor-based pagination. abstract CompletableFuture<ThreadQueryPageAsync>query(ThreadQueryParams params, RequestOptions requestOptions)CompletableFuture<ThreadQueryPageAsync>query(ThreadQueryParams params)CompletableFuture<ThreadQueryPageAsync>query(RequestOptions requestOptions)CompletableFuture<ThreadStatsResponse>stats(String threadId, ThreadStatsParams params)Alpha: The request and response contract may change; Compute aggregate stats for a single thread (turn count, latency percentiles, token/cost sums, and detail breakdowns) within a project. CompletableFuture<ThreadStatsResponse>stats(String threadId, ThreadStatsParams params, RequestOptions requestOptions)CompletableFuture<ThreadStatsResponse>stats(ThreadStatsParams params)abstract CompletableFuture<ThreadStatsResponse>stats(ThreadStatsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ThreadServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ThreadServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listTraces
CompletableFuture<ThreadListTracesPageAsync> listTraces(String threadId, ThreadListTracesParams params)
Alpha: The request and response contract may change; Retrieve all traces belonging to a specific thread within a project.
-
listTraces
CompletableFuture<ThreadListTracesPageAsync> listTraces(String threadId, ThreadListTracesParams params, RequestOptions requestOptions)
-
listTraces
CompletableFuture<ThreadListTracesPageAsync> listTraces(ThreadListTracesParams params)
-
listTraces
abstract CompletableFuture<ThreadListTracesPageAsync> listTraces(ThreadListTracesParams params, RequestOptions requestOptions)
-
query
CompletableFuture<ThreadQueryPageAsync> query()
Alpha: The request and response contract may change; Query threads within a project (session), with cursor-based pagination. Returns threads matching the given time range and optional filter.
-
query
abstract CompletableFuture<ThreadQueryPageAsync> query(ThreadQueryParams params, RequestOptions requestOptions)
-
query
CompletableFuture<ThreadQueryPageAsync> query(ThreadQueryParams params)
-
query
CompletableFuture<ThreadQueryPageAsync> query(RequestOptions requestOptions)
-
stats
CompletableFuture<ThreadStatsResponse> stats(String threadId, ThreadStatsParams params)
Alpha: The request and response contract may change; Compute aggregate stats for a single thread (turn count, latency percentiles, token/cost sums, and detail breakdowns) within a project.
-
stats
CompletableFuture<ThreadStatsResponse> stats(String threadId, ThreadStatsParams params, RequestOptions requestOptions)
-
stats
CompletableFuture<ThreadStatsResponse> stats(ThreadStatsParams params)
-
stats
abstract CompletableFuture<ThreadStatsResponse> stats(ThreadStatsParams params, RequestOptions requestOptions)
-
-
-
-