Class ValidateServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.async.examples.ValidateServiceAsync
public final class ValidateServiceAsyncImpl implements ValidateServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classValidateServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ValidateServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ValidateServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ExampleValidationResult>create(ValidateCreateParams params, RequestOptions requestOptions)CompletableFuture<List<ExampleValidationResult>>bulk(ValidateBulkParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ValidateServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ValidateServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<ExampleValidationResult> create(ValidateCreateParams params, RequestOptions requestOptions)
-
bulk
CompletableFuture<List<ExampleValidationResult>> bulk(ValidateBulkParams params, RequestOptions requestOptions)
-
-
-
-