Interface CommitService
-
- All Implemented Interfaces:
public interface CommitService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCommitService.WithRawResponseA view of CommitService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract CommitService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CommitService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CommitCreateResponse create(String repo, CommitCreateParams params)
Creates a new commit in a repository. Requires authentication and write access to the repository.
-
create
CommitCreateResponse create(String repo, CommitCreateParams params, RequestOptions requestOptions)
-
create
CommitCreateResponse create(CommitCreateParams params)
-
create
abstract CommitCreateResponse create(CommitCreateParams params, RequestOptions requestOptions)
-
retrieve
CommitRetrieveResponse retrieve(String commit, CommitRetrieveParams params)
Retrieves a specific commit by hash, tag, or "latest" for a repository. This endpoint supports both authenticated and unauthenticated access. Authenticated users can access private repos, while unauthenticated users can only access public repos. Commit resolution logic:
"latest" or empty: Get the most recent commit
Less than 8 characters: Only check for tags
8 or more characters: Prioritize commit hash over tag, check both
-
retrieve
CommitRetrieveResponse retrieve(String commit, CommitRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CommitRetrieveResponse retrieve(CommitRetrieveParams params)
-
retrieve
abstract CommitRetrieveResponse retrieve(CommitRetrieveParams params, RequestOptions requestOptions)
-
list
CommitListPage list(String repo, CommitListParams params)
Lists all commits for a repository with pagination support. This endpoint supports both authenticated and unauthenticated access. Authenticated users can access private repos, while unauthenticated users can only access public repos. The include_stats parameter controls whether download and view statistics are computed (defaults to true).
-
list
CommitListPage list(String repo, CommitListParams params, RequestOptions requestOptions)
-
list
CommitListPage list(CommitListParams params)
-
list
abstract CommitListPage list(CommitListParams params, RequestOptions requestOptions)
-
-
-
-