Class ExampleServiceImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.blocking.ExampleService
public final class ExampleServiceImpl implements ExampleService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.langchain.smith.services.blocking.ExampleService
create, delete, delete, delete, delete, delete, deleteAll, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveCount, retrieveCount, retrieveCount, update, update, update, update, update, uploadFromCsv, uploadFromCsv, uploadFromCsv -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ExampleService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ExampleService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
bulk
BulkService bulk()
-
validate
ValidateService validate()
-
create
Example create(ExampleCreateParams params, RequestOptions requestOptions)
-
retrieve
Example retrieve(ExampleRetrieveParams params, RequestOptions requestOptions)
-
update
ExampleUpdateResponse update(ExampleUpdateParams params, RequestOptions requestOptions)
-
list
List<Example> list(ExampleListParams params, RequestOptions requestOptions)
-
delete
ExampleDeleteResponse delete(ExampleDeleteParams params, RequestOptions requestOptions)
-
deleteAll
ExampleDeleteAllResponse deleteAll(ExampleDeleteAllParams params, RequestOptions requestOptions)
-
retrieveCount
Long retrieveCount(ExampleRetrieveCountParams params, RequestOptions requestOptions)
-
uploadFromCsv
List<Example> uploadFromCsv(ExampleUploadFromCsvParams params, RequestOptions requestOptions)
-
-
-
-