Class RunServiceImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.blocking.RunService
public final class RunServiceImpl implements RunService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRunServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RunService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RunServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RunIngestBatchResponseingestBatch(RunIngestBatchParams params, RequestOptions requestOptions)RunQueryResponsequery(RunQueryParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RunService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RunService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
ingestBatch
RunIngestBatchResponse ingestBatch(RunIngestBatchParams params, RequestOptions requestOptions)
-
query
RunQueryResponse query(RunQueryParams params, RequestOptions requestOptions)
-
-
-
-