Class SettingServiceImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.blocking.SettingService
public final class SettingServiceImpl implements SettingService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSettingServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SettingService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SettingServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AppHubCrudTenantsTenantlist(SettingListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SettingService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SettingService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
AppHubCrudTenantsTenant list(SettingListParams params, RequestOptions requestOptions)
-
-
-
-