Interface ThreadService
-
- All Implemented Interfaces:
public interface ThreadService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceThreadService.WithRawResponseA view of ThreadService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ThreadService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ThreadServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ThreadListTracesPagelistTraces(String threadId, ThreadListTracesParams params)Alpha: The request and response contract may change; Retrieve all traces belonging to a specific thread within a project. ThreadListTracesPagelistTraces(String threadId, ThreadListTracesParams params, RequestOptions requestOptions)ThreadListTracesPagelistTraces(ThreadListTracesParams params)abstract ThreadListTracesPagelistTraces(ThreadListTracesParams params, RequestOptions requestOptions)ThreadQueryPagequery()Alpha: The request and response contract may change; Query threads within a project (session), with cursor-based pagination. abstract ThreadQueryPagequery(ThreadQueryParams params, RequestOptions requestOptions)ThreadQueryPagequery(ThreadQueryParams params)ThreadQueryPagequery(RequestOptions requestOptions)ThreadStatsResponsestats(String threadId, ThreadStatsParams params)Alpha: The request and response contract may change; Compute aggregate stats for a single thread (turn count, latency percentiles, token/cost sums, and detail breakdowns) within a project. ThreadStatsResponsestats(String threadId, ThreadStatsParams params, RequestOptions requestOptions)ThreadStatsResponsestats(ThreadStatsParams params)abstract ThreadStatsResponsestats(ThreadStatsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ThreadService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ThreadService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listTraces
ThreadListTracesPage listTraces(String threadId, ThreadListTracesParams params)
Alpha: The request and response contract may change; Retrieve all traces belonging to a specific thread within a project.
-
listTraces
ThreadListTracesPage listTraces(String threadId, ThreadListTracesParams params, RequestOptions requestOptions)
-
listTraces
ThreadListTracesPage listTraces(ThreadListTracesParams params)
-
listTraces
abstract ThreadListTracesPage listTraces(ThreadListTracesParams params, RequestOptions requestOptions)
-
query
ThreadQueryPage query()
Alpha: The request and response contract may change; Query threads within a project (session), with cursor-based pagination. Returns threads matching the given time range and optional filter.
-
query
abstract ThreadQueryPage query(ThreadQueryParams params, RequestOptions requestOptions)
-
query
ThreadQueryPage query(ThreadQueryParams params)
-
query
ThreadQueryPage query(RequestOptions requestOptions)
-
stats
ThreadStatsResponse stats(String threadId, ThreadStatsParams params)
Alpha: The request and response contract may change; Compute aggregate stats for a single thread (turn count, latency percentiles, token/cost sums, and detail breakdowns) within a project.
-
stats
ThreadStatsResponse stats(String threadId, ThreadStatsParams params, RequestOptions requestOptions)
-
stats
ThreadStatsResponse stats(ThreadStatsParams params)
-
stats
abstract ThreadStatsResponse stats(ThreadStatsParams params, RequestOptions requestOptions)
-
-
-
-