Class ThreadServiceImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.blocking.ThreadService
public final class ThreadServiceImpl implements ThreadService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ThreadService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ThreadServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ThreadListTracesPagelistTraces(ThreadListTracesParams params, RequestOptions requestOptions)ThreadQueryPagequery(ThreadQueryParams params, RequestOptions requestOptions)ThreadStatsResponsestats(ThreadStatsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ThreadService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ThreadService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listTraces
ThreadListTracesPage listTraces(ThreadListTracesParams params, RequestOptions requestOptions)
-
query
ThreadQueryPage query(ThreadQueryParams params, RequestOptions requestOptions)
-
stats
ThreadStatsResponse stats(ThreadStatsParams params, RequestOptions requestOptions)
-
-
-
-