Class ThreadServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.langchain.smith.services.blocking.ThreadService.WithRawResponse
public final class ThreadServiceImpl.WithRawResponseImpl implements ThreadService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ThreadService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<ThreadListTracesPage>listTraces(ThreadListTracesParams params, RequestOptions requestOptions)HttpResponseFor<ThreadQueryPage>query(ThreadQueryParams params, RequestOptions requestOptions)HttpResponseFor<ThreadStatsResponse>stats(ThreadStatsParams params, RequestOptions requestOptions)-
Methods inherited from class com.langchain.smith.services.blocking.ThreadService.WithRawResponse
listTraces, listTraces, listTraces, query, query, query, stats, stats, stats -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
ThreadService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
listTraces
HttpResponseFor<ThreadListTracesPage> listTraces(ThreadListTracesParams params, RequestOptions requestOptions)
-
query
HttpResponseFor<ThreadQueryPage> query(ThreadQueryParams params, RequestOptions requestOptions)
-
stats
HttpResponseFor<ThreadStatsResponse> stats(ThreadStatsParams params, RequestOptions requestOptions)
-
-
-
-