Package com.langchain.smith.errors
Class LangChainRetryableException
-
- All Implemented Interfaces:
-
java.io.Serializable
public final class LangChainRetryableException extends LangChainException
Exception that indicates a transient error that can be retried.
When this exception is thrown during an HTTP request, the SDK will automatically retry the request up to the maximum number of retries.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringmessageprivate final Throwablecauseprivate final StringlocalizedMessageprivate final Array<Throwable>suppressedprivate Array<StackTraceElement>stackTrace
-
Constructor Summary
Constructors Constructor Description LangChainRetryableException(String message, Throwable cause)LangChainRetryableException(String message)LangChainRetryableException()
-
Method Summary
Modifier and Type Method Description -
Methods inherited from class kotlin.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Constructor Detail
-
LangChainRetryableException
LangChainRetryableException(String message, Throwable cause)
- Parameters:
message- A descriptive error messagecause- The underlying cause of this exception, if any
-
LangChainRetryableException
LangChainRetryableException(String message)
- Parameters:
message- A descriptive error message
-
LangChainRetryableException
LangChainRetryableException()
-
-
-
-