Class Example
-
- All Implemented Interfaces:
public final class ExampleExample schema.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExample.BuilderA builder for Example.
public final classExample.Inputspublic final classExample.AttachmentUrlspublic final classExample.Metadatapublic final classExample.Outputs
-
Method Summary
Modifier and Type Method Description final Stringid()final StringdatasetId()final Example.Inputsinputs()final Stringname()final Optional<Example.AttachmentUrls>attachmentUrls()final Optional<OffsetDateTime>createdAt()final Optional<Example.Metadata>metadata()final Optional<OffsetDateTime>modifiedAt()final Optional<Example.Outputs>outputs()final Optional<String>sourceRunId()final Optional<OffsetDateTime>sourceRunStartTime()final Optional<String>sourceSessionId()final Optional<String>sourceTraceId()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_datasetId()Returns the raw JSON value of datasetId. final JsonField<Example.Inputs>_inputs()Returns the raw JSON value of inputs. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Example.AttachmentUrls>_attachmentUrls()Returns the raw JSON value of attachmentUrls. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Example.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<OffsetDateTime>_modifiedAt()Returns the raw JSON value of modifiedAt. final JsonField<Example.Outputs>_outputs()Returns the raw JSON value of outputs. final JsonField<String>_sourceRunId()Returns the raw JSON value of sourceRunId. final JsonField<OffsetDateTime>_sourceRunStartTime()Returns the raw JSON value of sourceRunStartTime. final JsonField<String>_sourceSessionId()Returns the raw JSON value of sourceSessionId. final JsonField<String>_sourceTraceId()Returns the raw JSON value of sourceTraceId. final Map<String, JsonValue>_additionalProperties()final Example.BuildertoBuilder()final Examplevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Example.Builderbuilder()Returns a mutable builder for constructing an instance of Example. -
-
Method Detail
-
inputs
final Example.Inputs inputs()
-
attachmentUrls
final Optional<Example.AttachmentUrls> attachmentUrls()
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
metadata
final Optional<Example.Metadata> metadata()
-
modifiedAt
final Optional<OffsetDateTime> modifiedAt()
-
outputs
final Optional<Example.Outputs> outputs()
-
sourceRunId
final Optional<String> sourceRunId()
-
sourceRunStartTime
final Optional<OffsetDateTime> sourceRunStartTime()
-
sourceSessionId
final Optional<String> sourceSessionId()
-
sourceTraceId
final Optional<String> sourceTraceId()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_datasetId
final JsonField<String> _datasetId()
Returns the raw JSON value of datasetId.
Unlike datasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_inputs
final JsonField<Example.Inputs> _inputs()
Returns the raw JSON value of inputs.
Unlike inputs, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_attachmentUrls
final JsonField<Example.AttachmentUrls> _attachmentUrls()
Returns the raw JSON value of attachmentUrls.
Unlike attachmentUrls, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<Example.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_modifiedAt
final JsonField<OffsetDateTime> _modifiedAt()
Returns the raw JSON value of modifiedAt.
Unlike modifiedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_outputs
final JsonField<Example.Outputs> _outputs()
Returns the raw JSON value of outputs.
Unlike outputs, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceRunId
final JsonField<String> _sourceRunId()
Returns the raw JSON value of sourceRunId.
Unlike sourceRunId, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceRunStartTime
final JsonField<OffsetDateTime> _sourceRunStartTime()
Returns the raw JSON value of sourceRunStartTime.
Unlike sourceRunStartTime, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceSessionId
final JsonField<String> _sourceSessionId()
Returns the raw JSON value of sourceSessionId.
Unlike sourceSessionId, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceTraceId
final JsonField<String> _sourceTraceId()
Returns the raw JSON value of sourceTraceId.
Unlike sourceTraceId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Example.Builder toBuilder()
-
validate
final Example validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Example.Builder builder()
Returns a mutable builder for constructing an instance of Example.
The following fields are required:
.id() .datasetId() .inputs() .name()
-
-
-
-