Class ExampleUpdateParams
-
- All Implemented Interfaces:
-
com.langchain.smith.core.Params
public final class ExampleUpdateParams implements Params
Update a specific example.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleUpdateParams.BuilderA builder for ExampleUpdateParams.
public final classExampleUpdateParams.BodyUpdate class for Example.
public final classExampleUpdateParams.Inputspublic final classExampleUpdateParams.Metadatapublic final classExampleUpdateParams.Outputspublic final classExampleUpdateParams.Split
-
Method Summary
-
-
Method Detail
-
attachmentsOperations
final Optional<AttachmentsOperations> attachmentsOperations()
-
inputs
final Optional<ExampleUpdateParams.Inputs> inputs()
-
metadata
final Optional<ExampleUpdateParams.Metadata> metadata()
-
outputs
final Optional<ExampleUpdateParams.Outputs> outputs()
-
split
final Optional<ExampleUpdateParams.Split> split()
-
_attachmentsOperations
final JsonField<AttachmentsOperations> _attachmentsOperations()
Returns the raw JSON value of attachmentsOperations.
Unlike attachmentsOperations, this method doesn't throw if the JSON field has an unexpected type.
-
_datasetId
final JsonField<String> _datasetId()
Returns the raw JSON value of datasetId.
Unlike datasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_inputs
final JsonField<ExampleUpdateParams.Inputs> _inputs()
Returns the raw JSON value of inputs.
Unlike inputs, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<ExampleUpdateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_outputs
final JsonField<ExampleUpdateParams.Outputs> _outputs()
Returns the raw JSON value of outputs.
Unlike outputs, this method doesn't throw if the JSON field has an unexpected type.
-
_overwrite
final JsonField<Boolean> _overwrite()
Returns the raw JSON value of overwrite.
Unlike overwrite, this method doesn't throw if the JSON field has an unexpected type.
-
_split
final JsonField<ExampleUpdateParams.Split> _split()
Returns the raw JSON value of split.
Unlike split, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExampleUpdateParams.Builder toBuilder()
-
_body
final ExampleUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ExampleUpdateParams none()
-
builder
final static ExampleUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of ExampleUpdateParams.
-
-
-
-