Class ExampleValidationResult
-
- All Implemented Interfaces:
public final class ExampleValidationResultValidation result for Example, combining fields from Create/Base/Update schemas.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExampleValidationResult.BuilderA builder for ExampleValidationResult.
public final classExampleValidationResult.Inputspublic final classExampleValidationResult.Metadatapublic final classExampleValidationResult.Outputspublic final classExampleValidationResult.Split
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<OffsetDateTime>createdAt()final Optional<String>datasetId()final Optional<ExampleValidationResult.Inputs>inputs()final Optional<ExampleValidationResult.Metadata>metadata()final Optional<ExampleValidationResult.Outputs>outputs()final Optional<Boolean>overwrite()final Optional<String>sourceRunId()final Optional<ExampleValidationResult.Split>split()final Optional<Boolean>useSourceRunIo()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_datasetId()Returns the raw JSON value of datasetId. final JsonField<ExampleValidationResult.Inputs>_inputs()Returns the raw JSON value of inputs. final JsonField<ExampleValidationResult.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<ExampleValidationResult.Outputs>_outputs()Returns the raw JSON value of outputs. final JsonField<Boolean>_overwrite()Returns the raw JSON value of overwrite. final JsonField<String>_sourceRunId()Returns the raw JSON value of sourceRunId. final JsonField<ExampleValidationResult.Split>_split()Returns the raw JSON value of split. final JsonField<Boolean>_useSourceRunIo()Returns the raw JSON value of useSourceRunIo. final Map<String, JsonValue>_additionalProperties()final ExampleValidationResult.BuildertoBuilder()final ExampleValidationResultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExampleValidationResult.Builderbuilder()Returns a mutable builder for constructing an instance of ExampleValidationResult. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
inputs
final Optional<ExampleValidationResult.Inputs> inputs()
-
metadata
final Optional<ExampleValidationResult.Metadata> metadata()
-
outputs
final Optional<ExampleValidationResult.Outputs> outputs()
-
sourceRunId
final Optional<String> sourceRunId()
-
split
final Optional<ExampleValidationResult.Split> split()
-
useSourceRunIo
final Optional<Boolean> useSourceRunIo()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_datasetId
final JsonField<String> _datasetId()
Returns the raw JSON value of datasetId.
Unlike datasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_inputs
final JsonField<ExampleValidationResult.Inputs> _inputs()
Returns the raw JSON value of inputs.
Unlike inputs, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<ExampleValidationResult.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_outputs
final JsonField<ExampleValidationResult.Outputs> _outputs()
Returns the raw JSON value of outputs.
Unlike outputs, this method doesn't throw if the JSON field has an unexpected type.
-
_overwrite
final JsonField<Boolean> _overwrite()
Returns the raw JSON value of overwrite.
Unlike overwrite, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceRunId
final JsonField<String> _sourceRunId()
Returns the raw JSON value of sourceRunId.
Unlike sourceRunId, this method doesn't throw if the JSON field has an unexpected type.
-
_split
final JsonField<ExampleValidationResult.Split> _split()
Returns the raw JSON value of split.
Unlike split, this method doesn't throw if the JSON field has an unexpected type.
-
_useSourceRunIo
final JsonField<Boolean> _useSourceRunIo()
Returns the raw JSON value of useSourceRunIo.
Unlike useSourceRunIo, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExampleValidationResult.Builder toBuilder()
-
validate
final ExampleValidationResult validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExampleValidationResult.Builder builder()
Returns a mutable builder for constructing an instance of ExampleValidationResult.
-
-
-
-